@@ -3,7 +3,7 @@ package Log::Saftpresse;
 use Moose;
 
 # ABSTRACT: a modular logfile analyzer
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 use Log::Saftpresse::Log4perl;
 use Log::Saftpresse::Config;
@@ -93,20 +93,23 @@ sub run {
 	my $slurp = $self->slurp;
 	my $last_flush = time;
 
-	$log->debug('entering main loop');
+	$log->info('entering main loop');
 	for(;;) { # main loop
 		my $events;
 		if( $slurp->can_read(1) ) {
+      $log->debug('checking for new input...');
 			$events = $slurp->read_events;
 			foreach my $event ( @$events ) {
 				$self->analyzer->process_event( $event );
 			}
 		}
 		if( scalar @$events ) {
+      $log->debug('sending '.scalar(@$events).' events to outputs...');
 			$self->outputs->output( @$events );
 		}
 
 		if( $self->_need_flush_counters ){
+      $log->debug('flushing counters...');
 			$self->counter_outputs->output(
 				$self->analyzer->get_all_counters );
 			$self->_flushed_counters;
@@ -131,7 +134,7 @@ Log::Saftpresse - a modular logfile analyzer
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 Description
 
