@@ -3,10 +3,11 @@ package Log::Saftpresse::Analyzer;
 use Moose;
 
 # ABSTRACT: class to analyze log messages
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 use Log::Saftpresse::Notes;
 use Log::Saftpresse::Counters;
+use Log::Saftpresse::Log4perl;
 
 extends 'Log::Saftpresse::PluginContainer';
 
@@ -33,8 +34,13 @@ sub process_event {
 	my ( $self, $stash ) = @_;
 	
 	foreach my $plugin ( @{$self->plugins} ) {
-		my $ret = $plugin->process(
-			$stash, $self->notes );
+    my $ret;
+    eval {
+  		$ret = $plugin->process( $stash, $self->notes );
+    };
+    if( $@ ) {
+      $log->error('plugin '.$plugin->name.' failed: '.$@);
+    }
 		if( defined $ret && $ret eq 'next') {
 			last;
 		}
@@ -78,7 +84,7 @@ Log::Saftpresse::Analyzer - class to analyze log messages
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
