@@ -2,8 +2,10 @@ package Log::Saftpresse::Input::RELP;
 
 use Moose;
 
+use Log::Saftpresse::Log4perl;
+
 # ABSTRACT: RELP server input plugin for saftpresse
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 
 extends 'Log::Saftpresse::Input::Server';
@@ -34,6 +36,8 @@ sub cmd_open {
 	my ( $self, $conn, $frame ) = @_;
 	my $resp;
 
+  $log->debug('client announced: '.$frame->data);
+
 	if( $frame->data =~ /^relp_version=0/ ) {
 		$resp = Log::Saftpresse::Input::RELP::Frame->new_next_frame(
 			$frame,
@@ -53,6 +57,7 @@ sub cmd_open {
 				message => 'unsupported protocol version',
 			)->as_string,
 		);
+    $log->error('client uses unsupported RELP protocol version');
 	}
 
 	$conn->print( $resp->as_string );
@@ -64,6 +69,7 @@ sub cmd_close {
 	my ( $self, $conn, $frame ) = @_;
 	my $resp;
 
+  $log->info('peer '.$conn->peerhost.':'.$conn->peerport.' intialized connection shutdown');
 	$resp = Log::Saftpresse::Input::RELP::Frame->new_next_frame(
 		$frame,
 		command => 'rsp',
@@ -73,7 +79,7 @@ sub cmd_close {
 		)->as_string,
 	);
 	$conn->print( $resp->as_string );
-	$conn->close;
+	$self->shutdown_connection( $conn );
 
 	return;
 }
@@ -99,9 +105,7 @@ sub _read_frame {
 	my ( $self, $conn ) = @_;
 	my $frame;
 	
-	eval {
-		$frame = Log::Saftpresse::Input::RELP::Frame->new_from_fh($conn);
-	};
+	$frame = Log::Saftpresse::Input::RELP::Frame->new_from_fh($conn);
 
 	return( $frame );
 }
@@ -120,7 +124,7 @@ Log::Saftpresse::Input::RELP - RELP server input plugin for saftpresse
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 Description
 
