@@ -2,8 +2,10 @@ package Log::Saftpresse::Input::Server;
 
 use Moose;
 
+use Log::Saftpresse::Log4perl;
+
 # ABSTRACT: udp/tcp network server input plugin for saftpresse
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 
 extends 'Log::Saftpresse::Input';
@@ -21,6 +23,7 @@ has 'listener' => (
 	is => 'ro', isa => 'IO::Socket::INET', lazy => 1,
 	default => sub {
 		my $self = shift;
+    $log->info('setting up listener on '.$self->listen.':'.$self->port.'...');
 		my $l = IO::Socket::INET->new(
 			Listen => $self->connection_queue_size,
 			LocalAddr => $self->listen,
@@ -49,6 +52,7 @@ sub accept_new_connections {
 		$conn->blocking(0);
 		$self->io_select->add( $conn );
 		$self->handle_new_connection( $conn );
+    $log->info('accepted new connection '.$conn->fileno.' from '.$conn->peerhost.':'.$conn->peerport);
 	}
 	return;
 }
@@ -82,15 +86,33 @@ sub read_events {
 	my @ready = $self->io_select->can_read(0);
 	foreach my $conn ( @ready )  {
 		if( $conn->eof ) {
-			$self->handle_cleanup_connection( $conn );
-			$self->io_select->remove( $conn );
-			$conn->close;
+      $log->info('connection '.$conn->fileno.' closed by peer');
+      $self->shutdown_connection( $conn );
 		}
-		push( @events, $self->handle_data($conn) );
+    eval {
+		  push( @events, $self->handle_data($conn) );
+    };
+    if( $@ ) {
+      $log->error('error reading from connection '.$conn->fileno.': '.$@);
+      $self->shutdown_connection( $conn );
+    }
 	}
 	return @events;
 }
 
+sub shutdown_connection {
+  my ( $self, $conn ) = @_;
+
+  $log->info('removing connection '.$conn->fileno.'...');
+  eval {
+    $self->handle_cleanup_connection( $conn );
+    $self->io_select->remove( $conn );
+    $conn->close;
+  };
+
+  return;
+}
+
 sub handle_cleanup_connection {
 	my ( $self, $conn ) = @_;
 	return;
@@ -136,7 +158,7 @@ Log::Saftpresse::Input::Server - udp/tcp network server input plugin for saftpre
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 Description
 
