@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: logging for Log::Saftpresse
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 use Exporter;
 use Log::Log4perl qw(:levels);
@@ -35,15 +35,25 @@ sub init {
 			log4perl.appender.FileAppndr1.layout = $layout
 		});
 	} else {
+    my $appender = 'Log::Log4perl::Appender::ScreenColoredLevels';
+    my $colored = 1;
+    eval { require Log::Log4perl::Appender::ScreenColoredLevels; };
+    if( $@ ) {
+      $appender = 'Log::Log4perl::Appender::Screen';
+    }
 		Log::Log4perl->init(\ qq{
 			log4perl.rootLogger = $level, Screen
-			log4perl.appender.Screen = Log::Log4perl::Appender::Screen
+			log4perl.appender.Screen = $appender
 			log4perl.appender.Screen.stderr  = 0
 			log4perl.appender.Screen.layout = $layout
 		});
+    if( ! $colored ) {
+      $log->debug('disabled colored logging. (install Log::Log4perl::Appender::ScreenColoredLevels)');
+    }
 	}
 
 	$log = Log::Log4perl::get_logger;
+  $log->info('initialized logging with level '.$level);
 }
 
 sub level {
@@ -65,7 +75,7 @@ Log::Saftpresse::Log4perl - logging for Log::Saftpresse
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
