@@ -3,7 +3,9 @@ package Log::Saftpresse::PluginContainer;
 use Moose;
 
 # ABSTRACT: base class for classes holding plugins
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
+
+use Log::Saftpresse::Log4perl;
 
 has 'plugin_prefix' => (
 	is => 'rw', isa => 'Str',
@@ -27,6 +29,7 @@ sub load_plugin {
 	my $plugin_class = $self->plugin_prefix.$params{'module'};
 	my $plugin;
 
+  $log->info('loading plugin '.$name.' ('.$plugin_class.')...');
 	my $code = "require ".$plugin_class.";";
 	eval $code; ## no critic (ProhibitStringyEval)
 	if($@) {
@@ -78,7 +81,7 @@ Log::Saftpresse::PluginContainer - base class for classes holding plugins
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
