@@ -3,10 +3,12 @@ package Log::Saftpresse::Slurp;
 use Moose;
 
 # ABSTRACT: class to read log file inputs
-our $VERSION = '1.1'; # VERSION
+our $VERSION = '1.2'; # VERSION
 
 extends 'Log::Saftpresse::PluginContainer';
 
+use Log::Saftpresse::Log4perl;
+
 use IO::Select;
 use Time::HiRes qw( sleep gettimeofday tv_interval );
 
@@ -62,7 +64,12 @@ sub read_events {
 	foreach my $plugin ( @{$self->plugins} ) {
 		if( $plugin->can_read ) {
 			if( $plugin->eof ) { next; }
-			push( @events, $plugin->read_events );
+      eval {
+		  	push( @events, $plugin->read_events );
+      };
+      if( $@ ) {
+        $log->error('error while reading from plugin '.$plugin->name.': '.$@);
+      }
 		}
 		$eof = 0;
 	}
@@ -88,7 +95,7 @@ Log::Saftpresse::Slurp - class to read log file inputs
 
 =head1 VERSION
 
-version 1.1
+version 1.2
 
 =head1 AUTHOR
 
